@@ -1,12 +1,16 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
-#include <QtCore/QCoreApplication>
+#include <QtCore>;
+#include <QCoreApplication>;
 
 MainWindow::MainWindow(QWidget *parent)
     : QMainWindow(parent), ui(new Ui::MainWindow)
 {
     ui->setupUi(this);
+
+    ui->label->hide();
+
     netAccessMan = new QNetworkAccessManager(this);
     connect(netAccessMan, SIGNAL(finished(QNetworkReply*)), this, SLOT(downloadFinished(QNetworkReply*)));
     ui->plainTextEdit->hide();
@@ -82,9 +86,10 @@ void MainWindow::download(QString item){
 void MainWindow::on_btnSearch_clicked()
 {
     if (ui->edtSong->text().simplified().count()>0){
+	ui->plainTextEdit->hide();
 	download("http://goear.com/search.php?q="+ui->edtSong->text());
     }else{
-	//mostrar mensaje de error
+	ui->edtSong->setText("You Must Provide a Name");
     }
 }
 
@@ -150,7 +155,6 @@ void MainWindow::downloadFinished(QNetworkReply *reply)
 	}
     }else if (reply->header(QNetworkRequest::ContentTypeHeader).toString()=="audio/mpeg"){
 
-
 	//QString sf = "MP3 files (*.mp3)";
 	//QString name = QFileDialog::getSaveFileName(this, tr("Save File"),"/home/user/MyDocs/",tr("MP3 files (*.mp3)"),&sf,QFileDialog::DontUseNativeDialog);
 
@@ -162,6 +166,7 @@ void MainWindow::downloadFinished(QNetworkReply *reply)
 	file.open(QIODevice::WriteOnly);
 	QDataStream out(&file);
 	out << downloadedItem;
+	ui->plainTextEdit->hide();
 	//ui->edtSong->setText("Downloaded");
 
     }
@@ -175,6 +180,7 @@ void MainWindow::downloadFinished(QNetworkReply *reply)
 void MainWindow::on_btnDownload_clicked()
 {
     if (ui->lstItems->currentRow()>-1){
+	    ui->plainTextEdit->show();
 	    download("http://www.goear.com/tracker758.php?f="+links->at(ui->lstItems->currentRow()));
 	}
 }
